@@ -165,6 +165,7 @@ class PageObjectGenerator:
         self.logger.debug(step)
         template = self.env.get_template("page_object.py.j2")
         rendered = template.render(**template_data)
+        fixed_rendered = rendered.replace("&#39;", '"').replace("#39;", '"')
 
         step = "Формирование названия файла"
         self.logger.debug(step)
@@ -181,7 +182,7 @@ class PageObjectGenerator:
         path = os.path.join(output_dir, file_name)
         os.makedirs(os.path.dirname(path), exist_ok=True)
         with open(path, "w", encoding="utf-8") as f:
-            f.write(rendered)
+            f.write(fixed_rendered)
 
         self.logger.debug(f"Generated PageObject → {path}")
         return path, class_name
@@ -504,7 +505,7 @@ class PageObjectGenerator:
             "recycler_locator": recycler_locator
         }
 
-    def _node_to_locator(self, node: UiElementNode, only_id: bool = False) -> dict[str, str]:
+    def _node_to_locator(self, node: UiElementNode, only_id: bool = False) -> dict[str, Any]:
         """
         Converts UiElementNode to a locator dictionary for template.
 
@@ -513,7 +514,7 @@ class PageObjectGenerator:
             only_id (bool): Whether to return only resource-id
 
         Returns:
-            Dict[str, str]: Locator dictionary
+            dict[str, Any]: Locator dictionary
         """
         self.logger.debug(f"{get_current_func_name()}")
         if only_id and node.attrs.get("resource-id"):
